import { Chevron, ContentBox } from '@igem/ui-components'
import React from 'react'
import clsx from 'clsx'

interface InfoBoxProps {
  className?: string
  subTitle: string
  title: string
  shouldScrollToSection?: boolean
  children?: JSX.Element
}

const InfoBox = ({ className, subTitle, title, shouldScrollToSection = false, children }: InfoBoxProps): JSX.Element => {
  const onMoreInfoClick = (): void => {
    const element = document.getElementById(`link-group-${title.toLowerCase()}`)
    if (element !== undefined && element !== null) {
      const top =
        element.getBoundingClientRect().top +
        (window.top?.pageYOffset ?? 0) -
        200
      window.scrollTo({ top, behavior: 'smooth' })
    }
  }
  return (
    <div
      className={clsx(
        'h-full w-full flex info-box',
        className,
        shouldScrollToSection && 'cursor-pointer'
      )}
      onClick={() => shouldScrollToSection && onMoreInfoClick()}
    >
      <ContentBox>
        <div className='flex flex-col h-full ii-page-content'>
          <div className='text-gray-700 text-opacity-70'>
            {subTitle}
          </div>
          <h3 className='!my-3'>{title}</h3>
          {children}
          {shouldScrollToSection && (
            <div className='mx-auto mt-auto flex h-full items-end'>
              <button
                className='flex items-center text-green-500'
                onClick={onMoreInfoClick}
              >
                <div className='flex mt-3'>
                  <p className='ii-small-caps ii-text-sm'>More info</p>
                  <Chevron />
                </div>
              </button>
            </div>
          )}
        </div>
      </ContentBox>
    </div>
  )
}

export default InfoBox
