import React from 'react'
import clsx from 'clsx'

interface ItemWithDescriptionProps {
  item: JSX.Element | string | number
  description: string
  className?: {outerDiv?: string, description?: string, number?: string}
  descriptionClassname?: string
}

const ItemWithDescription = ({
  item,
  description,
  className
}: ItemWithDescriptionProps): JSX.Element => {
  const wrapItem = (
    <p className={clsx('ii-text-2xl font-bold', className?.number)}>
      {typeof item === 'string'
        ? item
        : (item as Number).toString().replace(/\B(?=(\d{3})+(?!\d))/g, ' ')}
    </p>
  )

  return (
    <div className={clsx('flex flex-col items-center my-3 item-with-description', className?.outerDiv)}>
      {React.isValidElement(item) ? item : wrapItem}
      <p className={clsx('ii-small-caps text-[0.9rem] opacity-70 mt-1.5', className?.description)}>
        {description}
      </p>
    </div>
  )
}

export default ItemWithDescription
